@@ -6,7 +6,7 @@ import logging
 import datetime as dt
 import numpy as np
 import pandas as pd
-from utils import HttpUtil
+from .utils import HttpUtil
 
 
 class ApiClient():
@@ -27,13 +27,15 @@ class ApiClient():
         api_urls = api_urls if api_urls is not None else {
             'api_query': '/updatemonitor/dict-index/exportData',  # query
             'api_import': '/updatemonitor/dict-index/importJson',  # insert
-            'api_delete': '/updatemonitor/dict-index/deleteDictIndexData'  # delete
+            'api_delete': '/updatemonitor/dict-index/deleteDictIndexData',  # delete
+            'api_dict': '/updatemonitor/dict-index/queryDictIndex'  # index dict
         }
         self.token = token
         self.host = 'http://' + host + ':' + str(port)
         self.api_query = self.host + api_urls['api_query']
         self.api_import = self.host + api_urls['api_import']
         self.api_delete = self.host + api_urls['api_delete']
+        self.api_dict = self.host + api_urls['api_dict']
         self.init_logger(log_level)
 
     def init_logger(self, log_level=logging.INFO):
@@ -45,6 +47,26 @@ class ApiClient():
         self.logger.setLevel(log_level)
         self.logger.addHandler(log_handler)
 
+    def get_idx_dict(self, idx):
+        '''
+        获取指标信息
+        :param idx: 指标id
+        :return:
+        '''
+        if idx is None or type(idx) != int: raise Exception('指标id不可为空且为int类型')
+
+        url = self.api_dict + f'?indexId={str(idx)}'
+        self.logger.debug('request: ' + url)
+        result = HttpUtil.request_post(url, None, headers={'token': self.token}, raw=False)
+        result = json.loads(result.decode('utf-8'))
+        self.logger.debug('result: ' + str(result))
+
+        if 'code' not in result or result['code'] != 200:
+            self.logger.error(result['msg'])
+            raise Exception(result['msg'])
+        self.logger.info(result['msg'])
+        return result['info']
+
     def get_series(self, ids, start_dt='2015-01-01', end_dt=None, column='id'):
         '''
         获取日期序列
@@ -125,9 +147,8 @@ class ApiClient():
         :return:
         '''
         ids = ids if type(ids) == list else [int(ids)]
-        url_api = self.api_delete
         for idx in ids:
-            url = url_api + f'?indexId={str(idx)}&startDate={start_dt}&endDate={end_dt}'
+            url = self.api_delete + f'?indexId={str(idx)}&startDate={start_dt}&endDate={end_dt}'
             # params = {'indexId': idx_id, 'startDate': start_dt, 'endDate': end_dt}
             self.logger.debug('request: ' + url)
             result = HttpUtil.request_post(url, None, headers={'token': self.token}, raw=False)
@@ -139,4 +160,4 @@ class ApiClient():
                 raise Exception(result['msg'])
             self.logger.info(result['msg'])
 
-        return True
\ No newline at end of file
+        return True
